appname = 'monocle_slider'
context_callback =  "'monocle_slide_models': Slide.objects.all(), 'monocle_slider_models': Slider.objects.all().filter(isShown=True)"
models = ['Slider', 'Slide']
included_app_reqs = [
]


# -*- coding: utf-8 -*-
from django.db import models

CHOICES_PAGIN = (('true', 'С пагинацией',), ('false', 'Без пагинации',))
CHOICES_ARROWS = (('true', 'Со стрелками',), ('false', 'Без стрелок',))

from filebrowser.fields import FileBrowseField

class Slider(models.Model):
    name = models.CharField(max_length=255, verbose_name= 'Название слайдера')
    text = models.TextField(verbose_name='Подпись')
    elem_number = models.PositiveSmallIntegerField(blank=False, default=1, verbose_name='Количество отображаемых слайдов')
    isShown = models.BooleanField(default=True, verbose_name= 'Показывать')
    arrows = models.CharField(max_length=5, choices=CHOICES_ARROWS, default='true', blank=False, verbose_name='Стрелки навигации')
    pagination = models.CharField(max_length=5, choices=CHOICES_PAGIN, default='true', blank=False, verbose_name='Пагинация')

    def __str__(self):
        return self.name

    class Meta:
        verbose_name_plural = u'Слайдеры'
        verbose_name = u'Слайдер'

class Slide(models.Model):
    name = models.CharField(max_length=255, verbose_name='Название')
    slider = models.ForeignKey('Slider', verbose_name= 'Слайдер')
    image = FileBrowseField(max_length=200, directory="'slider", extensions=[".jpg", ".png", ".jpeg", ".ico", ], blank=True, null=True, verbose_name= 'Изображение')
    text = models.TextField(verbose_name='Подпись', blank=True)
    isShown = models.BooleanField(default=True, verbose_name='Показывать слайд')
    position = models.PositiveSmallIntegerField(default=0)

    class Meta:
        verbose_name_plural = u'Слайды'
        verbose_name = u'Слайд'
        ordering = ['position']

from django.apps import AppConfig
class CustomAppConfig(AppConfig):
        name = 'apps.monocle_slider'
        verbose_name = 'Слайдер'


from django.contrib import admin
from .models import *
from grappelli.forms import GrappelliSortableHiddenMixin

from django_summernote.admin import SummernoteModelAdmin
from django_summernote.admin import SummernoteInlineModelAdmin

class SlideInline(GrappelliSortableHiddenMixin, admin.TabularInline, SummernoteInlineModelAdmin):
    model = Slide
    sortable_field_name = "position"
    extra = 0

    fieldsets = [
        ('Настройки слайда', {'fields': ['name', 'image', 'text'], 'classes': ['collapse']}),
        ('Дополнительно', {'fields': ['position', 'isShown'], 'classes': ['collapse']}),
    ]
    list_display = ('name', 'text', 'position',)

class SliderAdmin(SummernoteModelAdmin):
    list_display = ('name', 'elem_number', 'isShown',)
    list_editable = ('elem_number', 'isShown',)
    inlines = [SlideInline]

admin.site.register(Slider, SliderAdmin)
